@@ -1,43 +1,31 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-             (C) 1999 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "partmanager.h"
 
+#include "kparts_logging.h"
 #include "partactivateevent.h"
+
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
 #include "partselectevent.h"
+#endif
+
 #include "guiactivateevent.h"
 #include "part.h"
 
 #include <QApplication>
-#include <QScrollBar>
 #include <QMouseEvent>
-
-#include <QDebug>
-
-//#define DEBUG_PARTMANAGER
+#include <QScrollBar>
 
 using namespace KParts;
 
 namespace KParts
 {
-
 class PartManagerPrivate
 {
 public:
@@ -45,11 +33,15 @@ public:
     {
         m_activeWidget = nullptr;
         m_activePart = nullptr;
+
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
         m_selectedPart = nullptr;
         m_selectedWidget = nullptr;
+#endif
+
         m_bAllowNestedParts = false;
         m_bIgnoreScrollBars = false;
-        m_activationButtonMask = Qt::LeftButton | Qt::MidButton | Qt::RightButton;
+        m_activationButtonMask = Qt::LeftButton | Qt::MiddleButton | Qt::RightButton;
         m_reason = PartManager::NoReason;
         m_bIgnoreExplicitFocusRequest = false;
     }
@@ -61,19 +53,21 @@ public:
         switch (ev->type()) {
         case QEvent::MouseButtonPress:
         case QEvent::MouseButtonDblClick: {
+            // clang-format off
             QMouseEvent *mev = static_cast<QMouseEvent *>(ev);
             m_reason = mev->button() == Qt::LeftButton
                        ? PartManager::ReasonLeftClick
-                       : (mev->button() == Qt::MidButton
+                       : (mev->button() == Qt::MiddleButton
                           ? PartManager::ReasonMidClick
                           : PartManager::ReasonRightClick);
+            // clang-format on
             break;
         }
         case QEvent::FocusIn:
             m_reason = static_cast<QFocusEvent *>(ev)->reason();
             break;
         default:
-            qWarning() << "PartManagerPrivate::setReason got unexpected ev type " << ev->type();
+            qCWarning(KPARTSLOG) << "PartManagerPrivate::setReason got unexpected event type" << ev->type();
             break;
         }
     }
@@ -94,8 +88,10 @@ public:
 
     PartManager::SelectionPolicy m_policy;
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
     Part *m_selectedPart;
     QWidget *m_selectedWidget;
+#endif
 
     QList<const QWidget *> m_managedTopLevelWidgets;
     short int m_activationButtonMask;
@@ -108,9 +104,9 @@ public:
 }
 
 PartManager::PartManager(QWidget *parent)
-    : QObject(parent), d(new PartManagerPrivate)
+    : QObject(parent)
+    , d(new PartManagerPrivate)
 {
-
     qApp->installEventFilter(this);
 
     d->m_policy = Direct;
@@ -119,9 +115,9 @@ PartManager::PartManager(QWidget *parent)
 }
 
 PartManager::PartManager(QWidget *topLevel, QObject *parent)
-    : QObject(parent), d(new PartManagerPrivate)
+    : QObject(parent)
+    , d(new PartManagerPrivate)
 {
-
     qApp->installEventFilter(this);
 
     d->m_policy = Direct;
@@ -131,18 +127,16 @@ PartManager::PartManager(QWidget *topLevel, QObject *parent)
 
 PartManager::~PartManager()
 {
-    for (const QWidget *w : qAsConst(d->m_managedTopLevelWidgets)) {
-        disconnect(w, &QWidget::destroyed,
-                   this, &PartManager::slotManagedTopLevelWidgetDestroyed);
+    for (const QWidget *w : std::as_const(d->m_managedTopLevelWidgets)) {
+        disconnect(w, &QWidget::destroyed, this, &PartManager::slotManagedTopLevelWidgetDestroyed);
     }
 
-    for (Part *it : qAsConst(d->m_parts)) {
+    for (Part *it : std::as_const(d->m_parts)) {
         it->setManager(nullptr);
     }
 
     // core dumps ... setActivePart( 0 );
     qApp->removeEventFilter(this);
-    delete d;
 }
 
 void PartManager::setSelectionPolicy(SelectionPolicy policy)
@@ -187,10 +181,7 @@ short int PartManager::activationButtonMask() const
 
 bool PartManager::eventFilter(QObject *obj, QEvent *ev)
 {
-
-    if (ev->type() != QEvent::MouseButtonPress &&
-            ev->type() != QEvent::MouseButtonDblClick &&
-            ev->type() != QEvent::FocusIn) {
+    if (ev->type() != QEvent::MouseButtonPress && ev->type() != QEvent::MouseButtonDblClick && ev->type() != QEvent::FocusIn) {
         return false;
     }
 
@@ -200,19 +191,18 @@ bool PartManager::eventFilter(QObject *obj, QEvent *ev)
 
     QWidget *w = static_cast<QWidget *>(obj);
 
-    if (((w->windowFlags().testFlag(Qt::Dialog)) && w->isModal()) ||
-            (w->windowFlags().testFlag(Qt::Popup)) || (w->windowFlags().testFlag(Qt::Tool))) {
+    if (((w->windowFlags().testFlag(Qt::Dialog)) && w->isModal()) || (w->windowFlags().testFlag(Qt::Popup)) || (w->windowFlags().testFlag(Qt::Tool))) {
         return false;
     }
 
     QMouseEvent *mev = nullptr;
     if (ev->type() == QEvent::MouseButtonPress || ev->type() == QEvent::MouseButtonDblClick) {
         mev = static_cast<QMouseEvent *>(ev);
-#ifdef DEBUG_PARTMANAGER
-        qDebug() << "PartManager::eventFilter button: " << mev->button() << " " << "d->m_activationButtonMask=" << d->m_activationButtonMask;
-#endif
+
+        qCDebug(KPARTSLOG) << "PartManager::eventFilter button:" << mev->button() << "d->m_activationButtonMask=" << d->m_activationButtonMask;
+
         if ((mev->button() & d->m_activationButtonMask) == 0) {
-            return false;    // ignore this button
+            return false; // ignore this button
         }
     }
 
@@ -235,11 +225,11 @@ bool PartManager::eventFilter(QObject *obj, QEvent *ev)
             part = findPartFromWidget(w);
         }
 
-#ifdef DEBUG_PARTMANAGER
+        // clang-format off
         const char *evType = (ev->type() == QEvent::MouseButtonPress) ? "MouseButtonPress"
                              : (ev->type() == QEvent::MouseButtonDblClick) ? "MouseButtonDblClick"
                              : (ev->type() == QEvent::FocusIn) ? "FocusIn" : "OTHER! ERROR!";
-#endif
+        // clang-format on
         if (part) { // We found a part whose widget is w
             if (d->m_policy == PartManager::TriState) {
                 if (ev->type() == QEvent::MouseButtonDblClick) {
@@ -247,46 +237,55 @@ bool PartManager::eventFilter(QObject *obj, QEvent *ev)
                         return false;
                     }
 
-#ifdef DEBUG_PARTMANAGER
-                    qDebug() << "PartManager::eventFilter dblclick -> setActivePart" << part;
-#endif
+                    qCDebug(KPARTSLOG) << "PartManager::eventFilter dblclick -> setActivePart" << part;
+
                     d->setReason(ev);
                     setActivePart(part, w);
                     d->m_reason = NoReason;
                     return true;
                 }
 
-                if ((d->m_selectedWidget != w || d->m_selectedPart != part) &&
-                        (d->m_activeWidget != w || d->m_activePart != part)) {
+                if (
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
+                    (d->m_selectedWidget != w || d->m_selectedPart != part) &&
+#endif
+                    (d->m_activeWidget != w || d->m_activePart != part)) {
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
                     if (part->isSelectable()) {
                         setSelectedPart(part, w);
                     } else {
-#ifdef DEBUG_PARTMANAGER
-                        qDebug() << "Part " << part << " (non-selectable) made active because " << w->metaObject()->className() << " got event" << " " << evType;
 #endif
+                        qCDebug(KPARTSLOG) << "Part" << part << "(non-selectable) made active because" << w->metaObject()->className() << "got event" << evType;
+
                         d->setReason(ev);
                         setActivePart(part, w);
                         d->m_reason = NoReason;
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
                     }
-                    return true;
-                } else if (d->m_selectedWidget == w && d->m_selectedPart == part) {
-#ifdef DEBUG_PARTMANAGER
-                    qDebug() << "Part " << part << " made active (from selected) because " << w->metaObject()->className() << " got event" << " " << evType;
 #endif
+                    return true;
+                }
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
+                else if (d->m_selectedWidget == w && d->m_selectedPart == part) {
+                    qCDebug(KPARTSLOG) << "Part" << part << "made active (from selected) because" << w->metaObject()->className() << "got event" << evType;
+
                     d->setReason(ev);
                     setActivePart(part, w);
                     d->m_reason = NoReason;
                     return true;
-                } else if (d->m_activeWidget == w && d->m_activePart == part) {
+                }
+#endif
+                else if (d->m_activeWidget == w && d->m_activePart == part) {
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
                     setSelectedPart(nullptr);
+#endif
                     return false;
                 }
 
                 return false;
             } else if (part != d->m_activePart && d->allowExplicitFocusEvent(ev)) {
-#ifdef DEBUG_PARTMANAGER
-                qDebug() << "Part " << part << " made active because " << w->metaObject()->className() << " got event" << " " << evType;
-#endif
+                qCDebug(KPARTSLOG) << "Part" << part << "made active because" << w->metaObject()->className() << "got event" << evType;
+
                 d->setReason(ev);
                 setActivePart(part, w);
                 d->m_reason = NoReason;
@@ -297,25 +296,21 @@ bool PartManager::eventFilter(QObject *obj, QEvent *ev)
 
         w = w->parentWidget();
 
-        if (w && (((w->windowFlags() & Qt::Dialog) && w->isModal()) ||
-                  (w->windowFlags() & Qt::Popup) || (w->windowFlags() & Qt::Tool))) {
-#ifdef DEBUG_PARTMANAGER
-            qDebug() << QString("No part made active although %1/%2 got event - loop aborted").arg(obj->objectName()).arg(obj->metaObject()->className());
-#endif
+        if (w && (((w->windowFlags() & Qt::Dialog) && w->isModal()) || (w->windowFlags() & Qt::Popup) || (w->windowFlags() & Qt::Tool))) {
+            qCDebug(KPARTSLOG) << "No part made active although" << obj->objectName() << "/" << obj->metaObject()->className() << "got event - loop aborted";
+
             return false;
         }
-
     }
 
-#ifdef DEBUG_PARTMANAGER
-    qDebug() << QString("No part made active although %1/%2 got event").arg(obj->objectName()).arg(obj->metaObject()->className());
-#endif
+    qCDebug(KPARTSLOG) << "No part made active although" << obj->objectName() << "/" << obj->metaObject()->className() << "got event - loop aborted";
+
     return false;
 }
 
 Part *PartManager::findPartFromWidget(QWidget *widget, const QPoint &pos)
 {
-    for (auto *p : qAsConst(d->m_parts)) {
+    for (auto *p : std::as_const(d->m_parts)) {
         Part *part = p->hitTest(widget, pos);
         if (part && d->m_parts.contains(part)) {
             return part;
@@ -326,7 +321,7 @@ Part *PartManager::findPartFromWidget(QWidget *widget, const QPoint &pos)
 
 Part *PartManager::findPartFromWidget(QWidget *widget)
 {
-    for (auto *part : qAsConst(d->m_parts)) {
+    for (auto *part : std::as_const(d->m_parts)) {
         if (widget == part->widget()) {
             return part;
         }
@@ -340,9 +335,7 @@ void PartManager::addPart(Part *part, bool setActive)
 
     // don't add parts more than once :)
     if (d->m_parts.contains(part)) {
-#ifdef DEBUG_PARTMANAGER
-        qWarning() << part << " already added";
-#endif
+        qCWarning(KPARTSLOG) << part << " already added";
         return;
     }
 
@@ -356,20 +349,20 @@ void PartManager::addPart(Part *part, bool setActive)
         if (QWidget *w = part->widget()) {
             // Prevent focus problems
             if (w->focusPolicy() == Qt::NoFocus) {
-                qWarning() << "Part '" << part->objectName() << "' has a widget "
-                           << w->objectName() << " with a focus policy of NoFocus. It should have at least a"
-                           << "ClickFocus policy, for part activation to work well.";
+                qCWarning(KPARTSLOG) << "Part '" << part->objectName() << "' has a widget " << w->objectName()
+                                     << "with a focus policy of NoFocus. It should have at least a"
+                                     << "ClickFocus policy, for part activation to work well.";
             }
             if (part->widget() && part->widget()->focusPolicy() == Qt::TabFocus) {
-                qWarning() << "Part '" << part->objectName() << "' has a widget "
-                           << w->objectName() << " with a focus policy of TabFocus. It should have at least a"
-                           << "ClickFocus policy, for part activation to work well.";
+                qCWarning(KPARTSLOG) << "Part '" << part->objectName() << "' has a widget " << w->objectName()
+                                     << "with a focus policy of TabFocus. It should have at least a"
+                                     << "ClickFocus policy, for part activation to work well.";
             }
             w->setFocus();
             w->show();
         }
     }
-    emit partAdded(part);
+    Q_EMIT partAdded(part);
 }
 
 void PartManager::removePart(Part *part)
@@ -383,19 +376,21 @@ void PartManager::removePart(Part *part)
     Q_UNUSED(nb); // no warning in release mode
     part->setManager(nullptr);
 
-    emit partRemoved(part);
+    Q_EMIT partRemoved(part);
 
     if (part == d->m_activePart) {
         setActivePart(nullptr);
     }
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
     if (part == d->m_selectedPart) {
         setSelectedPart(nullptr);
     }
+#endif
 }
 
 void PartManager::replacePart(Part *oldPart, Part *newPart, bool setActive)
 {
-    //qDebug() << "replacePart " << oldPart->name() << "-> " << newPart->name() << " setActive=" << setActive;
+    // qCDebug(KPARTSLOG) << "replacePart" << oldPart->name() << "->" << newPart->name() << "setActive=" << setActive;
     // This methods does exactly removePart + addPart but without calling setActivePart(0) in between
     if (!d->m_parts.contains(oldPart)) {
         qFatal("Can't remove part %s, not in KPartManager's list.", oldPart->objectName().toLocal8Bit().constData());
@@ -405,7 +400,7 @@ void PartManager::replacePart(Part *oldPart, Part *newPart, bool setActive)
     d->m_parts.removeAll(oldPart);
     oldPart->setManager(nullptr);
 
-    emit partRemoved(oldPart);
+    Q_EMIT partRemoved(oldPart);
 
     addPart(newPart, setActive);
 }
@@ -413,12 +408,12 @@ void PartManager::replacePart(Part *oldPart, Part *newPart, bool setActive)
 void PartManager::setActivePart(Part *part, QWidget *widget)
 {
     if (part && !d->m_parts.contains(part)) {
-        qWarning() << "trying to activate a non-registered part!" << part->objectName();
+        qCWarning(KPARTSLOG) << "trying to activate a non-registered part!" << part->objectName();
         return; // don't allow someone call setActivePart with a part we don't know about
     }
 
-    //check whether nested parts are disallowed and activate the top parent part then, by traversing the
-    //tree recursively (Simon)
+    // check whether nested parts are disallowed and activate the top parent part then, by traversing the
+    // tree recursively (Simon)
     if (part && !d->m_bAllowNestedParts) {
         QObject *parentPart = part->parent(); // ### this relies on people using KParts::Factory!
         KParts::Part *parPart = ::qobject_cast<KParts::Part *>(parentPart);
@@ -428,21 +423,20 @@ void PartManager::setActivePart(Part *part, QWidget *widget)
         }
     }
 
-#ifdef DEBUG_PARTMANAGER
-    qDebug() << "PartManager::setActivePart d->m_activePart=" << d->m_activePart << "<->part=" << part
-             << " d->m_activeWidget=" << d->m_activeWidget << "<->widget=" << widget;
-#endif
+    qCDebug(KPARTSLOG) << "PartManager::setActivePart d->m_activePart=" << d->m_activePart << "<->part=" << part << "d->m_activeWidget=" << d->m_activeWidget
+                       << "<->widget=" << widget;
 
     // don't activate twice
-    if (d->m_activePart && part && d->m_activePart == part &&
-            (!widget || d->m_activeWidget == widget)) {
+    if (d->m_activePart && part && d->m_activePart == part && (!widget || d->m_activeWidget == widget)) {
         return;
     }
 
     KParts::Part *oldActivePart = d->m_activePart;
     QWidget *oldActiveWidget = d->m_activeWidget;
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
     setSelectedPart(nullptr);
+#endif
 
     d->m_activePart = part;
     d->m_activeWidget = widget;
@@ -454,8 +448,7 @@ void PartManager::setActivePart(Part *part, QWidget *widget)
         PartActivateEvent ev(false, oldActivePart, oldActiveWidget);
         QApplication::sendEvent(oldActivePart, &ev);
         if (oldActiveWidget) {
-            disconnect(oldActiveWidget, &QWidget::destroyed,
-                       this, &PartManager::slotWidgetDestroyed);
+            disconnect(oldActiveWidget, &QWidget::destroyed, this, &PartManager::slotWidgetDestroyed);
             QApplication::sendEvent(oldActiveWidget, &ev);
         }
 
@@ -471,18 +464,16 @@ void PartManager::setActivePart(Part *part, QWidget *widget)
         PartActivateEvent ev(true, d->m_activePart, d->m_activeWidget);
         QApplication::sendEvent(d->m_activePart, &ev);
         if (d->m_activeWidget) {
-            connect(d->m_activeWidget, &QWidget::destroyed,
-                    this, &PartManager::slotWidgetDestroyed);
+            connect(d->m_activeWidget, &QWidget::destroyed, this, &PartManager::slotWidgetDestroyed);
             QApplication::sendEvent(d->m_activeWidget, &ev);
         }
     }
     // Set the new active instance
-    //setActiveComponent(d->m_activePart ? d->m_activePart->componentData() : KComponentData::mainComponent());
+    // setActiveComponent(d->m_activePart ? d->m_activePart->componentData() : KComponentData::mainComponent());
 
-#ifdef DEBUG_PARTMANAGER
-    qDebug() << this << " emitting activePartChanged " << d->m_activePart;
-#endif
-    emit activePartChanged(d->m_activePart);
+    qCDebug(KPARTSLOG) << this << "emitting activePartChanged" << d->m_activePart;
+
+    Q_EMIT activePartChanged(d->m_activePart);
 }
 
 Part *PartManager::activePart() const
@@ -492,9 +483,10 @@ Part *PartManager::activePart() const
 
 QWidget *PartManager::activeWidget() const
 {
-    return  d->m_activeWidget;
+    return d->m_activeWidget;
 }
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
 void PartManager::setSelectedPart(Part *part, QWidget *widget)
 {
     if (part == d->m_selectedPart && widget == d->m_selectedWidget) {
@@ -523,16 +515,21 @@ void PartManager::setSelectedPart(Part *part, QWidget *widget)
         QApplication::sendEvent(d->m_selectedWidget, &ev);
     }
 }
+#endif
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
 Part *PartManager::selectedPart() const
 {
     return d->m_selectedPart;
 }
+#endif
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 72)
 QWidget *PartManager::selectedWidget() const
 {
     return d->m_selectedWidget;
 }
+#endif
 
 void PartManager::slotObjectDestroyed()
 {
@@ -544,9 +541,9 @@ void PartManager::slotWidgetDestroyed()
 {
     // qDebug();
     if (static_cast<const QWidget *>(sender()) == d->m_activeWidget) {
-        setActivePart(nullptr);    //do not remove the part because if the part's widget dies, then the
+        setActivePart(nullptr); // do not remove the part because if the part's widget dies, then the
     }
-    //part will delete itself anyway, invoking removePart() in its destructor
+    // part will delete itself anyway, invoking removePart() in its destructor
 }
 
 const QList<Part *> PartManager::parts() const
@@ -565,8 +562,7 @@ void PartManager::addManagedTopLevelWidget(const QWidget *topLevel)
     }
 
     d->m_managedTopLevelWidgets.append(topLevel);
-    connect(topLevel, &QWidget::destroyed,
-            this, &PartManager::slotManagedTopLevelWidgetDestroyed);
+    connect(topLevel, &QWidget::destroyed, this, &PartManager::slotManagedTopLevelWidgetDestroyed);
 }
 
 void PartManager::removeManagedTopLevelWidget(const QWidget *topLevel)
